@@ -360,6 +360,7 @@ class PseudoAgentDBBindingController(port_binding.PortBindingController):
                 }
                 # Substitute identifiers and Convert JSON string to dict
                 hconfig_conf_json = Template(jsonutils.dumps(details))
+                # pylint: disable=too-many-function-args
                 substituted_str = hconfig_conf_json.safe_substitute(subs_ids)
                 vnic['vif_details'] = jsonutils.loads(substituted_str)
         return hconfig
@@ -375,16 +376,6 @@ class PseudoAgentDBBindingController(port_binding.PortBindingController):
             return
 
         for raw_hconfig in agentdb:
-            # TODO(yamahata): don't poll hostconfig and update aliveness
-            # on hostconfig change of ODL. it's also necessary for
-            # scalability regarding to the number of compute nodes.
-            if not raw_hconfig['alive']:
-                LOG.warning(
-                    "Refusing to bind port %(pid)s to dead pseudo agent: "
-                    "%(agent)s",
-                    {'pid': port_context.current['id'], 'agent': raw_hconfig})
-                continue
-
             # do any $identifier substitution
             hconfig = self._substitute_hconfig_tmpl(port_context, raw_hconfig)
 
