@@ -13,8 +13,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 import abc
+from unittest import mock
 
-import mock
 from oslotest import base
 import six
 from six.moves.urllib import parse as url_parse
@@ -23,11 +23,11 @@ from ceilometer import service
 from networking_odl.ceilometer.network.statistics.opendaylight_v2 import driver
 from oslo_utils import uuidutils
 
-ADMIN_ID = uuidutils.generate_uuid()
-PORT_1_TENANT_ID = uuidutils.generate_uuid()
-PORT_2_TENANT_ID = uuidutils.generate_uuid()
-PORT_1_ID = uuidutils.generate_uuid()
-PORT_2_ID = uuidutils.generate_uuid()
+ADMIN_ID = str(uuidutils.generate_uuid())
+PORT_1_TENANT_ID = str(uuidutils.generate_uuid())
+PORT_2_TENANT_ID = str(uuidutils.generate_uuid())
+PORT_1_ID = str(uuidutils.generate_uuid())
+PORT_2_ID = str(uuidutils.generate_uuid())
 
 
 @six.add_metaclass(abc.ABCMeta)
@@ -52,7 +52,11 @@ class _Base(base.BaseTestCase):
         self.addCleanup(mock.patch.stopall)
         conf = service.prepare_service([], [])
         self.driver = driver.OpenDaylightDriver(conf)
-
+        ks_client = mock.Mock(auth_token='fake_token')
+        ks_client.projects.find.return_value = mock.Mock(name='admin',
+                                                         id=ADMIN_ID)
+        self.ks_client = mock.patch('ceilometer.keystone_client.get_client',
+                                    return_value=ks_client).start()
         self.get_statistics = mock.patch(
             'networking_odl.ceilometer.network.statistics.opendaylight_v2.'
             'client.SwitchStatisticsAPIClient.get_statistics',
@@ -134,28 +138,27 @@ class TestOpenDayLightDriverSimple(_Base):
 
     switch_data = {
         "flow_capable_switches": [{
-            "packet_in_messages_received": 501,
-            "packet_out_messages_sent": 300,
-            "ports": 1,
-            "flow_datapath_id": 55120148545607,
-            "tenant_id": ADMIN_ID,
+            "packet_in_messages_received": "501",
+            "packet_out_messages_sent": "300",
+            "ports": "1",
+            "flow_datapath_id": "55120148545607",
             "switch_port_counters": [{
-                "bytes_received": 0,
-                "bytes_sent": 0,
-                "duration": 600,
-                "packets_internal_received": 444,
-                "packets_internal_sent": 0,
-                "packets_received": 0,
-                "packets_received_drop": 0,
-                "packets_received_error": 0,
-                "packets_sent": 0,
-                "port_id": 4,
+                "bytes_received": "0",
+                "bytes_sent": "0",
+                "duration": "600",
+                "packets_internal_received": "444",
+                "packets_internal_sent": "0",
+                "packets_received": "0",
+                "packets_received_drop": "0",
+                "packets_received_error": "0",
+                "packets_sent": "0",
+                "port_id": "4",
                 "tenant_id": PORT_1_TENANT_ID,
                 "uuid": PORT_1_ID
             }],
             "table_counters": [{
-                "flow_count": 90,
-                "table_id": 0
+                "flow_count": "90",
+                "table_id": "0"
             }]
         }]
     }
@@ -266,7 +269,7 @@ class TestOpenDayLightDriverSimple(_Base):
 
     def test_meter_port(self):
         expected_data = [
-            (1, str(PORT_1_ID),
+            (1, PORT_1_ID,
              {'controller': 'OpenDaylight_V2'},
              PORT_1_TENANT_ID),
         ]
@@ -274,7 +277,7 @@ class TestOpenDayLightDriverSimple(_Base):
 
     def test_meter_port_uptime(self):
         expected_data = [
-            (600, str(PORT_1_ID),
+            (600, PORT_1_ID,
              {'controller': 'OpenDaylight_V2'},
              PORT_1_TENANT_ID),
         ]
@@ -282,7 +285,7 @@ class TestOpenDayLightDriverSimple(_Base):
 
     def test_meter_port_receive_packets(self):
         expected_data = [
-            (0, str(PORT_1_ID),
+            (0, PORT_1_ID,
              {'controller': 'OpenDaylight_V2'},
              PORT_1_TENANT_ID),
         ]
@@ -290,7 +293,7 @@ class TestOpenDayLightDriverSimple(_Base):
 
     def test_meter_port_transmit_packets(self):
         expected_data = [
-            (0, str(PORT_1_ID),
+            (0, PORT_1_ID,
              {'controller': 'OpenDaylight_V2'},
              PORT_1_TENANT_ID),
         ]
@@ -298,7 +301,7 @@ class TestOpenDayLightDriverSimple(_Base):
 
     def test_meter_port_receive_bytes(self):
         expected_data = [
-            (0, str(PORT_1_ID),
+            (0, PORT_1_ID,
              {'controller': 'OpenDaylight_V2'},
              PORT_1_TENANT_ID),
         ]
@@ -306,7 +309,7 @@ class TestOpenDayLightDriverSimple(_Base):
 
     def test_meter_port_transmit_bytes(self):
         expected_data = [
-            (0, str(PORT_1_ID),
+            (0, PORT_1_ID,
              {'controller': 'OpenDaylight_V2'},
              PORT_1_TENANT_ID),
         ]
@@ -314,7 +317,7 @@ class TestOpenDayLightDriverSimple(_Base):
 
     def test_meter_port_receive_drops(self):
         expected_data = [
-            (0, str(PORT_1_ID),
+            (0, PORT_1_ID,
              {'controller': 'OpenDaylight_V2'},
              PORT_1_TENANT_ID),
         ]
@@ -322,7 +325,7 @@ class TestOpenDayLightDriverSimple(_Base):
 
     def test_meter_port_receive_errors(self):
         expected_data = [
-            (0, str(PORT_1_ID),
+            (0, PORT_1_ID,
              {'controller': 'OpenDaylight_V2'},
              PORT_1_TENANT_ID),
         ]
@@ -342,70 +345,67 @@ class TestOpenDayLightDriverComplex(_Base):
 
     switch_data = {
         "flow_capable_switches": [{
-            "packet_in_messages_received": 501,
-            "packet_out_messages_sent": 300,
-            "ports": 3,
-            "flow_datapath_id": 55120148545607,
+            "packet_in_messages_received": "501",
+            "packet_out_messages_sent": "300",
+            "ports": "3",
+            "flow_datapath_id": "55120148545607",
             "switch_port_counters": [{
-                "bytes_received": 0,
-                "bytes_sent": 512,
-                "duration": 200,
-                "packets_internal_received": 444,
-                "packets_internal_sent": 0,
-                "packets_received": 10,
-                "packets_received_drop": 0,
-                "packets_received_error": 0,
-                "packets_sent": 0,
-                "port_id": 3,
-                "tenant_id": ADMIN_ID
+                "bytes_received": "0",
+                "bytes_sent": "512",
+                "duration": "200",
+                "packets_internal_received": "444",
+                "packets_internal_sent": "0",
+                "packets_received": "10",
+                "packets_received_drop": "0",
+                "packets_received_error": "0",
+                "packets_sent": "0",
+                "port_id": "3",
             }, {
-                "bytes_received": 9800,
-                "bytes_sent": 6540,
-                "duration": 150,
-                "packets_internal_received": 0,
-                "packets_internal_sent": 7650,
-                "packets_received": 20,
-                "packets_received_drop": 0,
-                "packets_received_error": 0,
-                "packets_sent": 0,
-                "port_id": 2,
+                "bytes_received": "9800",
+                "bytes_sent": "6540",
+                "duration": "150",
+                "packets_internal_received": "0",
+                "packets_internal_sent": "7650",
+                "packets_received": "20",
+                "packets_received_drop": "0",
+                "packets_received_error": "0",
+                "packets_sent": "0",
+                "port_id": "2",
                 "tenant_id": PORT_2_TENANT_ID,
                 "uuid": PORT_2_ID
             }, {
-                "bytes_received": 100,
-                "bytes_sent": 840,
-                "duration": 100,
-                "packets_internal_received": 984,
-                "packets_internal_sent": 7950,
-                "packets_received": 9900,
-                "packets_received_drop": 1500,
-                "packets_received_error": 1000,
-                "packets_sent": 7890,
-                "port_id": 1,
+                "bytes_received": "100",
+                "bytes_sent": "840",
+                "duration": "100",
+                "packets_internal_received": "984",
+                "packets_internal_sent": "7950",
+                "packets_received": "9900",
+                "packets_received_drop": "1500",
+                "packets_received_error": "1000",
+                "packets_sent": "7890",
+                "port_id": "1",
                 "tenant_id": PORT_1_TENANT_ID,
                 "uuid": PORT_1_ID
             }],
             "table_counters": [{
-                "flow_count": 90,
-                "table_id": 10
+                "flow_count": "90",
+                "table_id": "10"
             }, {
-                "flow_count": 80,
-                "table_id": 20
+                "flow_count": "80",
+                "table_id": "20"
             }],
-            "tenant_id": ADMIN_ID
         }, {
-            "packet_in_messages_received": 0,
-            "packet_out_messages_sent": 0,
-            "ports": 0,
-            "flow_datapath_id": 55120148545555,
+            "packet_in_messages_received": "0",
+            "packet_out_messages_sent": "0",
+            "ports": "0",
+            "flow_datapath_id": "55120148545555",
             "table_counters": [{
-                "flow_count": 5,
-                "table_id": 10
+                "flow_count": "5",
+                "table_id": "10"
             }, {
-                "flow_count": 3,
-                "table_id": 20
+                "flow_count": "3",
+                "table_id": "20"
             }],
-            "tenant_id": ADMIN_ID
         }]
     }
 
@@ -611,10 +611,10 @@ class TestOpenDayLightDriverComplex(_Base):
 
     def test_meter_port(self):
         expected_data = [
-            (1, str(PORT_2_ID),
+            (1, PORT_2_ID,
              {'controller': 'OpenDaylight_V2'},
              PORT_2_TENANT_ID),
-            (1, str(PORT_1_ID),
+            (1, PORT_1_ID,
              {'controller': 'OpenDaylight_V2'},
              PORT_1_TENANT_ID),
         ]
@@ -622,10 +622,10 @@ class TestOpenDayLightDriverComplex(_Base):
 
     def test_meter_port_uptime(self):
         expected_data = [
-            (150, str(PORT_2_ID),
+            (150, PORT_2_ID,
              {'controller': 'OpenDaylight_V2'},
              PORT_2_TENANT_ID),
-            (100, str(PORT_1_ID),
+            (100, PORT_1_ID,
              {'controller': 'OpenDaylight_V2'},
              PORT_1_TENANT_ID),
         ]
@@ -633,10 +633,10 @@ class TestOpenDayLightDriverComplex(_Base):
 
     def test_meter_port_receive_packets(self):
         expected_data = [
-            (20, str(PORT_2_ID),
+            (20, PORT_2_ID,
              {'controller': 'OpenDaylight_V2'},
              PORT_2_TENANT_ID),
-            (9900, str(PORT_1_ID),
+            (9900, PORT_1_ID,
              {'controller': 'OpenDaylight_V2'},
              PORT_1_TENANT_ID),
         ]
@@ -644,10 +644,10 @@ class TestOpenDayLightDriverComplex(_Base):
 
     def test_meter_port_transmit_packets(self):
         expected_data = [
-            (0, str(PORT_2_ID),
+            (0, PORT_2_ID,
              {'controller': 'OpenDaylight_V2'},
              PORT_2_TENANT_ID),
-            (7890, str(PORT_1_ID),
+            (7890, PORT_1_ID,
              {'controller': 'OpenDaylight_V2'},
              PORT_1_TENANT_ID),
         ]
@@ -655,10 +655,10 @@ class TestOpenDayLightDriverComplex(_Base):
 
     def test_meter_port_receive_bytes(self):
         expected_data = [
-            (9800, str(PORT_2_ID),
+            (9800, PORT_2_ID,
              {'controller': 'OpenDaylight_V2'},
              PORT_2_TENANT_ID),
-            (100, str(PORT_1_ID),
+            (100, PORT_1_ID,
              {'controller': 'OpenDaylight_V2'},
              PORT_1_TENANT_ID),
         ]
@@ -666,10 +666,10 @@ class TestOpenDayLightDriverComplex(_Base):
 
     def test_meter_port_transmit_bytes(self):
         expected_data = [
-            (6540, str(PORT_2_ID),
+            (6540, PORT_2_ID,
              {'controller': 'OpenDaylight_V2'},
              PORT_2_TENANT_ID),
-            (840, str(PORT_1_ID),
+            (840, PORT_1_ID,
              {'controller': 'OpenDaylight_V2'},
              PORT_1_TENANT_ID),
         ]
@@ -677,10 +677,10 @@ class TestOpenDayLightDriverComplex(_Base):
 
     def test_meter_port_receive_drops(self):
         expected_data = [
-            (0, str(PORT_2_ID),
+            (0, PORT_2_ID,
              {'controller': 'OpenDaylight_V2'},
              PORT_2_TENANT_ID),
-            (1500, str(PORT_1_ID),
+            (1500, PORT_1_ID,
              {'controller': 'OpenDaylight_V2'},
              PORT_1_TENANT_ID),
         ]
@@ -688,10 +688,10 @@ class TestOpenDayLightDriverComplex(_Base):
 
     def test_meter_port_receive_errors(self):
         expected_data = [
-            (0, str(PORT_2_ID),
+            (0, PORT_2_ID,
              {'controller': 'OpenDaylight_V2'},
              PORT_2_TENANT_ID),
-            (1000, str(PORT_1_ID),
+            (1000, PORT_1_ID,
              {'controller': 'OpenDaylight_V2'},
              PORT_1_TENANT_ID),
         ]
